@@ -5,7 +5,7 @@ NAME = 'gourd'
 BACKLOG = 65535
 
 # 仅对 tcpserver 有效
-TERMINATOR = '\r\n'
+TERMINATOR = '\n'
 
 # 仅对 udpserver 有效
 PACKAGE_SIZE = 64 * 1024    # 64K
